"use strict";

const execAllModule = require("fix-esm").require("execall");
// HACK: This works around a bizarre issue where `fix-esm` behaves differently in deployment than locally
const execAll = typeof execAllModule === "function" ? execAllModule : execAllModule.default;

const regexPossibleModelNumber = /(?:^|\s)[A-Z0-9-]{3,}(?:\s|$)/g;
const regexNumber = /[0-9]/;
const regexLetter = /[A-Z]/;

// To be considered a 'model number', a space-delimited substring of all-caps/numeric must contain at least one letter and one number.

module.exports = function extractModelNumber(string) {
	let candidates = execAll(regexPossibleModelNumber, string)
		.filter(({ match }) => regexNumber.test(match) && regexLetter.test(match));

	if (candidates.length === 1) {
		return candidates[0].match;
	} else if (candidates.length === 0) {
		throw new Error(`No model number found in string`);
	} else {
		throw new Error(`More than one potential model number found in string: ${candidates.join(", ")}`);
	}
};
